==> nextcloud-app-news-14.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/is.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Beiðni mistókst, engin nettenging tiltæk!",
    "Request unauthorized. Are you logged in?" : "Beiðni ekki heimiluð. Ertu skráð/ur inn?",
    "Request forbidden. Are you an admin?" : "Beiðni bönnuð. Ertu kerfisstjóri?",
    "Token expired or app not enabled! Reload the page!" : "Kenniteikn er útrunnið eða forrit ekki virkt! Þú ættir að hlaða síðunni aftur inn!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Innri miðlaravilla! Athugaðu skrána data/nextcloud.log fyrir nánari upplýsingar!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Fyrirspurn brást, Nextcloud er núna í viðhaldsham.",
    "Can not add feed: Exists already" : "Gat ekki bætt við streymi: streymið er þegar til",
    "Articles without feed" : "Greinar án fréttastreymis",
    "Can not add folder: Exists already" : "Gat ekki bætt við möppu: mappan er þegar til",
    "News" : "Fréttir",
    "An RSS/Atom feed reader" : "RSS/Atom streymislesari",
    "Use system cron for updates" : "Nota kerfis-cron fyrir uppfærslur",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Gerðu þetta óvirkt ef þú keyrir sérsniðið uppfærsluforrit eins og Python uppærsluforritið sem innifalið er í smáforritinu",
    "Purge interval" : "Millibil förgunar",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Lágmarksfjöldi sekúndna þar til eydd streymi og möppur eru fjarlægð úr gagnagrunninum; gildi undir 60 sekúndum eru hunsuð",
    "Maximum read count per feed" : "Hámarkfjöldi lestra á hvert streymi",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Skilgeinir fjölda greina sem hægt er að lesa í hverju fréttastreymi og sem ekki verður eytt við hreinsunarverkefni: ef eldri greinar birtast aftur eftir að hafa verið lesnar, hækkaðu þá þetta gildi; neikvæð gildi eins og -1 slökkva alfarið á þessum eiginleika",
    "Maximum redirects" : "Hámarks endurbeiningar",
    "How many redirects the feed fetcher should follow" : "Hversu mörgum endurbeiningum streymissugan á að fylgja",
    "Maximum feed page size" : "Hámarksstærð streymissíðu",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Hámarksstærð streymis í bætum. Ef RSS eða Atom-streymi eru stærri en þetta gildi, er hætt við uppfærslu",
    "Feed fetcher timeout" : "Tímamörk streymissugu",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Hámarksfjöldi sekúndna sem beðið er eftir að RSS eða Atom-streymi hlaðist inn; ef það tekur lengri tíma er hætt við uppfærslu",
    "Explore Service URL" : "Skoða slóð á þjónustu (URL)",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Ef það er uppgefið, mun slóð þessarar þjónustu verða könnuð fyrir birtingu á streymum sem birtst í streymavafurshlutanum. Til að fara aftur í innbyggða vafurshlutann, skildu þá þetta eftir autt",
    "For more information check the wiki" : "Skoðaðu wiki-vefsvæðið til að fá frekari upplýsingar",
    "Saved" : "Vistað",
    "Download" : "Niðurhal",
    "Close" : "Loka",
    "filter" : "sía",
    "Language" : "Tungumál",
    "Subscribe" : "Áskrift",
    "Got more awesome feeds? Share them with us!" : "Áttu fleiri frábæra fréttastrauma? Deildu þeim með okkur!",
    "No articles available" : "Engar greinar tiltækar",
    "No unread articles available" : "Engar ólesnar greinar tiltækar",
    "Open website" : "Opna vefsvæði",
    "Star article" : "Stjörnumerkja grein",
    "Unstar article" : "Taka stjörnugjöf af grein",
    "Keep article unread" : "Halda greininni sem ólesinni",
    "Remove keep article unread" : "Fjarlægja að halda greininni sem ólesinni",
    "by" : "eftir",
    "from" : "frá",
    "Play audio" : "Spila hljóð",
    "Download audio" : "Sækja hljóð",
    "Download video" : "Sækja myndskeið",
    "Keyboard shortcut" : "Flýtilykill",
    "Description" : "Lýsing",
    "right" : "hægri",
    "Jump to next article" : "Hoppa á næstu grein",
    "left" : "vinstri",
    "Jump to previous article" : "Hoppa á fyrri grein",
    "Toggle star article" : "Víxla stjörnumerkingu af/á grein",
    "Star article and jump to next one" : "Stjörnumerkja grein og hoppa í næstu",
    "Toggle keep current article unread" : "Víxla af/á að halda greininni sem ólesinni",
    "Open article in new tab" : "Opna grein í nýjum flipa",
    "Toggle expand article in compact view" : "Víxla útflettingu greinar af/á í þjappaðri sýn",
    "Refresh" : "Endurlesa",
    "Load next feed" : "Hlaða inn næsta streymi",
    "Load previous feed" : "Hlaða inn fyrra streymi",
    "Load next folder" : "Hlaða inn næstu möppu",
    "Load previous folder" : "Hlaða inn fyrri möppu",
    "Scroll to active navigation entry" : "Skruna á virka færslu í flakki",
    "Focus search field" : "Færa virkni í leitarreitinn",
    "Mark current article's feed/folder read" : "Merkja streymi/möppu núverandi greinar sem lesið",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eða webcron fannst! Fréttastraumar þínir verða ekki uppfærðir!",
    "How to set up the operating system cron" : "Hvernig á að setja upp cron-þjónustu stýrikerfis",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Setja upp og stilla hraðvirkari samhliða uppfærslueiningu sem notar API-forritsviðmót fréttaforritsins",
    "Web address" : "Veffang",
    "Feed exists already!" : "Streymið er þegar til!",
    "Folder" : "Mappa",
    "No folder" : "Engin mappa",
    "New folder" : "Ný mappa",
    "Folder name" : "Nafn möppu",
    "Go back" : "Til baka",
    "Folder exists already!" : "Mappan er þegar til!",
    "Credentials" : "Auðkenni",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth auðkenni verða að geymast ódulrituð! Hver sá sem hefur aðgang að þjóninum eða gagnagrunninum mun hafa aðgang að þeim!",
    "Username" : "Notandanafn",
    "Password" : "Lykilorð",
    "New Folder" : "Ný mappa",
    "Create" : "Búa til",
    "Explore" : "Skoða",
    "Update failed more than 50 times" : "Uppfærsla mistókst oftar en 50 sinnum",
    "Deleted feed" : "Eyða streymi",
    "Undo delete feed" : "Afturkalla eyðingu á streymi",
    "Rename" : "Endurnefna",
    "Menu" : "Valmynd",
    "Mark read" : "Merkja sem lesið",
    "Unpin from top" : "Aftengja frá topphluta",
    "Pin to top" : "Tengja á topphluta",
    "Newest first" : "Nýjast fyrst",
    "Oldest first" : "Elsta fyrst",
    "Default order" : "Sjálfgefin röðun",
    "Enable full text" : "Virkja allan texta",
    "Disable full text" : "Afvirkja allan texta",
    "Unread updated" : "Ólesið uppfært",
    "Ignore updated" : "Hunsa uppfært",
    "Open feed URL" : "Opna URL-slóð streymis",
    "Delete" : "Eyða",
    "Dismiss" : "Hafna",
    "Collapse" : "Fella saman",
    "Deleted folder" : "Eydd mappa",
    "Undo delete folder" : "Afturkalla eyðingu á möppu",
    "Starred" : "Stjörnumerkt",
    "Unread articles" : "Ólesnar greinar",
    "All articles" : "Allar greinar",
    "Settings" : "Stillingar",
    "Disable mark read through scrolling" : "Gera óvirkt að merkja sem lesið við skrun",
    "Compact view" : "Þjöppuð sýn",
    "Expand articles on key navigation" : "Virkja útflettingu greina við flakk með lyklaborði",
    "Show all articles" : "Birta allar greinar",
    "Reverse ordering (oldest on top)" : "Öfug röðun (elsta efst)",
    "Subscriptions (OPML)" : "Áskriftir (OPML)",
    "Import" : "Flytja inn",
    "Export" : "Flytja út",
    "Error when importing: File does not contain valid OPML" : "Villa við innflutning: skrá inniheldur ekki gilt OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Villa við innflutning: OPML inniheldur hvorki fréttastrauma né möppur",
    "Unread/Starred Articles" : "Ólesnar/stjörnumerktar greinar",
    "Error when importing: file does not contain valid JSON" : "Villa við innflutning: skrá inniheldur ekki gilt JSON",
    "Help" : "Hjálp",
    "Keyboard shortcuts" : "Flýtilyklar",
    "Documentation" : "Hjálparskjöl",
    "Report a bug" : "Tilkynna um villu"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-app-news-14.1.11-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/is.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Beiðni mistókst, engin nettenging tiltæk!",
    "Request unauthorized. Are you logged in?" : "Beiðni ekki heimiluð. Ertu skráð/ur inn?",
    "Request forbidden. Are you an admin?" : "Beiðni bönnuð. Ertu kerfisstjóri?",
    "Token expired or app not enabled! Reload the page!" : "Kenniteikn er útrunnið eða forrit ekki virkt! Þú ættir að hlaða síðunni aftur inn!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Innri miðlaravilla! Athugaðu skrána data/nextcloud.log fyrir nánari upplýsingar!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Fyrirspurn brást, Nextcloud er núna í viðhaldsham.",
    "Can not add feed: Unable to parse feed" : "Gat ekki bætt við streymi: Það tókst ekki að þátta streymið",
    "Can not add feed: Exists already" : "Gat ekki bætt við streymi: streymið er þegar til",
    "Articles without feed" : "Greinar án fréttastreymis",
    "Can not add folder: Exists already" : "Gat ekki bætt við möppu: mappan er þegar til",
    "News" : "Fréttir",
    "An RSS/Atom feed reader" : "RSS/Atom streymislesari",
    "Use system cron for updates" : "Nota kerfis-cron fyrir uppfærslur",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Gerðu þetta óvirkt ef þú keyrir sérsniðið uppfærsluforrit eins og Python uppærsluforritið sem innifalið er í smáforritinu",
    "Purge interval" : "Millibil förgunar",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Lágmarksfjöldi sekúndna þar til eydd streymi og möppur eru fjarlægð úr gagnagrunninum; gildi undir 60 sekúndum eru hunsuð",
    "Maximum read count per feed" : "Hámarkfjöldi lestra á hvert streymi",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Skilgeinir fjölda greina sem hægt er að lesa í hverju fréttastreymi og sem ekki verður eytt við hreinsunarverkefni: ef eldri greinar birtast aftur eftir að hafa verið lesnar, hækkaðu þá þetta gildi; neikvæð gildi eins og -1 slökkva alfarið á þessum eiginleika",
    "Maximum redirects" : "Hámarks endurbeiningar",
    "How many redirects the feed fetcher should follow" : "Hversu mörgum endurbeiningum streymissugan á að fylgja",
    "Maximum feed page size" : "Hámarksstærð streymissíðu",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Hámarksstærð streymis í bætum. Ef RSS eða Atom-streymi eru stærri en þetta gildi, er hætt við uppfærslu",
    "Feed fetcher timeout" : "Tímamörk streymissugu",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Hámarksfjöldi sekúndna sem beðið er eftir að RSS eða Atom-streymi hlaðist inn; ef það tekur lengri tíma er hætt við uppfærslu",
    "Explore Service URL" : "Skoða slóð á þjónustu (URL)",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Ef það er uppgefið, mun slóð þessarar þjónustu verða könnuð fyrir birtingu á streymum sem birtst í streymavafurshlutanum. Til að fara aftur í innbyggða vafurshlutann, skildu þá þetta eftir autt",
    "For more information check the wiki" : "Skoðaðu wiki-vefsvæðið til að fá frekari upplýsingar",
    "Saved" : "Vistað",
    "Download" : "Niðurhal",
    "Close" : "Loka",
    "filter" : "sía",
    "Language" : "Tungumál",
    "Subscribe" : "Áskrift",
    "Got more awesome feeds? Share them with us!" : "Áttu fleiri frábæra fréttastrauma? Deildu þeim með okkur!",
    "No articles available" : "Engar greinar tiltækar",
    "No unread articles available" : "Engar ólesnar greinar tiltækar",
    "Open website" : "Opna vefsvæði",
    "Star article" : "Stjörnumerkja grein",
    "Unstar article" : "Taka stjörnugjöf af grein",
    "Keep article unread" : "Halda greininni sem ólesinni",
    "Remove keep article unread" : "Fjarlægja að halda greininni sem ólesinni",
    "by" : "eftir",
    "from" : "frá",
    "Play audio" : "Spila hljóð",
    "Download audio" : "Sækja hljóð",
    "Download video" : "Sækja myndskeið",
    "Keyboard shortcut" : "Flýtilykill",
    "Description" : "Lýsing",
    "right" : "hægri",
    "Jump to next article" : "Hoppa á næstu grein",
    "left" : "vinstri",
    "Jump to previous article" : "Hoppa á fyrri grein",
    "Toggle star article" : "Víxla stjörnumerkingu af/á grein",
    "Star article and jump to next one" : "Stjörnumerkja grein og hoppa í næstu",
    "Toggle keep current article unread" : "Víxla af/á að halda greininni sem ólesinni",
    "Open article in new tab" : "Opna grein í nýjum flipa",
    "Toggle expand article in compact view" : "Víxla útflettingu greinar af/á í þjappaðri sýn",
    "Refresh" : "Endurlesa",
    "Load next feed" : "Hlaða inn næsta streymi",
    "Load previous feed" : "Hlaða inn fyrra streymi",
    "Load next folder" : "Hlaða inn næstu möppu",
    "Load previous folder" : "Hlaða inn fyrri möppu",
    "Scroll to active navigation entry" : "Skruna á virka færslu í flakki",
    "Focus search field" : "Færa virkni í leitarreitinn",
    "Mark current article's feed/folder read" : "Merkja streymi/möppu núverandi greinar sem lesið",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eða webcron fannst! Fréttastraumar þínir verða ekki uppfærðir!",
    "How to set up the operating system cron" : "Hvernig á að setja upp cron-þjónustu stýrikerfis",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Setja upp og stilla hraðvirkari samhliða uppfærslueiningu sem notar API-forritsviðmót fréttaforritsins",
    "Web address" : "Veffang",
    "Feed exists already!" : "Streymið er þegar til!",
    "Folder" : "Mappa",
    "No folder" : "Engin mappa",
    "New folder" : "Ný mappa",
    "Folder name" : "Nafn möppu",
    "Go back" : "Til baka",
    "Folder exists already!" : "Mappan er þegar til!",
    "Credentials" : "Auðkenni",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth auðkenni verða að geymast ódulrituð! Hver sá sem hefur aðgang að þjóninum eða gagnagrunninum mun hafa aðgang að þeim!",
    "Username" : "Notandanafn",
    "Password" : "Lykilorð",
    "New Folder" : "Ný mappa",
    "Create" : "Búa til",
    "Explore" : "Skoða",
    "Update failed more than 50 times" : "Uppfærsla mistókst oftar en 50 sinnum",
    "Deleted feed" : "Eyða streymi",
    "Undo delete feed" : "Afturkalla eyðingu á streymi",
    "Rename" : "Endurnefna",
    "Menu" : "Valmynd",
    "Mark read" : "Merkja sem lesið",
    "Unpin from top" : "Aftengja frá topphluta",
    "Pin to top" : "Tengja á topphluta",
    "Newest first" : "Nýjast fyrst",
    "Oldest first" : "Elsta fyrst",
    "Default order" : "Sjálfgefin röðun",
    "Enable full text" : "Virkja allan texta",
    "Disable full text" : "Afvirkja allan texta",
    "Unread updated" : "Ólesið uppfært",
    "Ignore updated" : "Hunsa uppfært",
    "Open feed URL" : "Opna URL-slóð streymis",
    "Delete" : "Eyða",
    "Dismiss" : "Hafna",
    "Collapse" : "Fella saman",
    "Deleted folder" : "Eydd mappa",
    "Undo delete folder" : "Afturkalla eyðingu á möppu",
    "Starred" : "Stjörnumerkt",
    "Unread articles" : "Ólesnar greinar",
    "All articles" : "Allar greinar",
    "Settings" : "Stillingar",
    "Disable mark read through scrolling" : "Gera óvirkt að merkja sem lesið við skrun",
    "Compact view" : "Þjöppuð sýn",
    "Expand articles on key navigation" : "Virkja útflettingu greina við flakk með lyklaborði",
    "Show all articles" : "Birta allar greinar",
    "Reverse ordering (oldest on top)" : "Öfug röðun (elsta efst)",
    "Subscriptions (OPML)" : "Áskriftir (OPML)",
    "Import" : "Flytja inn",
    "Export" : "Flytja út",
    "Error when importing: File does not contain valid OPML" : "Villa við innflutning: skrá inniheldur ekki gilt OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Villa við innflutning: OPML inniheldur hvorki fréttastrauma né möppur",
    "Unread/Starred Articles" : "Ólesnar/stjörnumerktar greinar",
    "Error when importing: file does not contain valid JSON" : "Villa við innflutning: skrá inniheldur ekki gilt JSON",
    "Help" : "Hjálp",
    "Keyboard shortcuts" : "Flýtilyklar",
    "Documentation" : "Hjálparskjöl",
    "Report a bug" : "Tilkynna um villu"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
